@@ -30,16 +30,16 @@
 
 // Interactive help.
 
-typedef struct A68_INFO A68_INFO;
+typedef struct A68G_INFO A68G_INFO;
 
-struct A68_INFO
+struct A68G_INFO
 {
   char *cat;
   char *term;
   char *def;
 };
 
-static A68_INFO info_text[] = {
+static A68G_INFO info_text[] = {
   {"monitor", "breakpoint clear [all]", "clear breakpoints and watchpoint expression"},
   {"monitor", "breakpoint clear breakpoints", "clear breakpoints"},
   {"monitor", "breakpoint clear watchpoint", "clear watchpoint expression"},
@@ -128,11 +128,11 @@ static A68_INFO info_text[] = {
 void print_info (FILE_T f, char *prompt, int k)
 {
   if (prompt != NO_TEXT) {
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s %s: %s.", prompt, TERM (&info_text[k]), DEF (&info_text[k])) >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s %s: %s.", prompt, TERM (&info_text[k]), DEF (&info_text[k])) >= 0);
   } else {
-    ASSERT (a68g_bufprt (A68 (output_line), SNPRINTF_SIZE, "%s: %s.", TERM (&info_text[k]), DEF (&info_text[k])) >= 0);
+    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "%s: %s.", TERM (&info_text[k]), DEF (&info_text[k])) >= 0);
   }
-  WRITE (f, A68 (output_line));
+  WRITE (f, A68G (output_line));
   WRITELN (f, "");
 }
 
