@@ -141,15 +141,15 @@ void cannot_coerce (NODE_T * p, MOID_T * from, MOID_T * to, int context, int def
   char *txt = mode_error_text (p, from, to, context, deflex, 1);
   if (att == STOP) {
     if (strlen (txt) == 0) {
-      diagnostic (A68_ERROR, p, "M cannot be coerced to M in C context", from, to, context);
+      diagnostic (A68G_ERROR, p, "M cannot be coerced to M in C context", from, to, context);
     } else {
-      diagnostic (A68_ERROR, p, "Y in C context", txt, context);
+      diagnostic (A68G_ERROR, p, "Y in C context", txt, context);
     }
   } else {
     if (strlen (txt) == 0) {
-      diagnostic (A68_ERROR, p, "M cannot be coerced to M in C-A", from, to, context, att);
+      diagnostic (A68G_ERROR, p, "M cannot be coerced to M in C-A", from, to, context, att);
     } else {
-      diagnostic (A68_ERROR, p, "Y in C-A", txt, context, att);
+      diagnostic (A68G_ERROR, p, "Y in C-A", txt, context, att);
     }
   }
 }
@@ -159,12 +159,12 @@ void cannot_coerce (NODE_T * p, MOID_T * from, MOID_T * to, int context, int def
 void warn_for_voiding (NODE_T * p, SOID_T * x, SOID_T * y, int c)
 {
   (void) c;
-  if (CAST (x) == A68_FALSE) {
+  if (CAST (x) == A68G_FALSE) {
     if (MOID (x) == M_VOID && MOID (y) != M_ERROR && !(MOID (y) == M_VOID || !is_nonproc (MOID (y)))) {
       if (IS (p, FORMULA)) {
-        diagnostic (A68_WARNING | A68_FORCE_DIAGNOSTICS, p, WARNING_VOIDED, MOID (y));
+        diagnostic (A68G_WARNING | A68G_FORCE_DIAGNOSTICS, p, WARNING_VOIDED, MOID (y));
       } else {
-        diagnostic (A68_WARNING, p, WARNING_VOIDED, MOID (y));
+        diagnostic (A68G_WARNING, p, WARNING_VOIDED, MOID (y));
       }
     }
   }
@@ -178,7 +178,7 @@ void semantic_pitfall (NODE_T * p, MOID_T * m, int c, int u)
 //                   REF INT i := LOC INT := 0, which should probably be
 //                   REF INT i = LOC INT := 0.
   if (IS (p, u)) {
-    diagnostic (A68_WARNING, p, WARNING_UNINTENDED, MOID (p), u, m, c);
+    diagnostic (A68G_WARNING, p, WARNING_UNINTENDED, MOID (p), u, m, c);
   } else if (is_one_of (p, UNIT, TERTIARY, SECONDARY, PRIMARY, STOP)) {
     semantic_pitfall (SUB (p), m, c, u);
   }
