@@ -29,7 +29,7 @@
 #include "a68g-mp.h"
 #include "a68g-double.h"
 
-#if (A68_LEVEL >= 3)
+#if (A68G_LEVEL >= 3)
 
 #if defined (HAVE_GNU_MPFR)
 
@@ -58,7 +58,7 @@ void mp_to_mpfr (NODE_T * p, MP_T * z, mpfr_t * x, int digits)
 // This routine looks a lot like "strtod".
   (void) p;
   mpfr_set_ui (*x, 0, DEFAULT);
-  if (MP_EXPONENT (z) * (MP_T) LOG_MP_RADIX > (MP_T) A68_REAL_MIN_EXP) {
+  if (MP_EXPONENT (z) * (MP_T) LOG_MP_RADIX > (MP_T) A68G_REAL_MIN_EXP) {
     BOOL_T neg = MP_DIGIT (z, 1) < 0;
     mpfr_t term, W;
     mpfr_inits2 (MPFR_MP_BITS, term, W, NO_MPFR);
@@ -161,7 +161,7 @@ void mpfr_beta_inc (mpfr_t Ix, mpfr_t s, mpfr_t t, mpfr_t x, mpfr_rnd_t rnd)
     mpfr_set_nan (Ix);
   } else {
     mpfr_t a, b, c, d, e, F, T, W;
-    int N, m, cont = A68_TRUE;
+    int N, m, cont = A68G_TRUE;
     mpfr_prec_t lim = 2 * mpfr_get_prec (x);
     mpfr_inits2 (MPFR_MP_BITS, a, b, c, d, e, F, T, W, NO_MPFR);
 // Rapid convergence when x < (s+1)/(s+t+2)
@@ -221,7 +221,7 @@ void mpfr_beta_inc (mpfr_t Ix, mpfr_t s, mpfr_t t, mpfr_t x, mpfr_rnd_t rnd)
       mpfr_mul (F, F, c, rnd);
       mpfr_mul (F, F, d, rnd);
       if (mpfr_cmp (F, W) == 0) {
-        cont = A68_FALSE;
+        cont = A68G_FALSE;
         errno = 0;
       } else {
         mpfr_set (W, F, rnd);
@@ -303,11 +303,11 @@ void genie_mpfr_inverf_mp (NODE_T * _p_)
 void genie_mpfr_inverfc_mp (NODE_T * p)
 {
   MOID_T *mode = MOID (p);
-  ADDR_T pop_sp = A68_SP;
+  ADDR_T pop_sp = A68G_SP;
   int digits = DIGITS (mode), size = SIZE (mode);
   MP_T *z = (MP_T *) STACK_OFFSET (-size);
   one_minus_mp (p, z, z, digits);
-  A68_SP = pop_sp;
+  A68G_SP = pop_sp;
   genie_inverf_mp (p);
 }
 
@@ -347,31 +347,31 @@ void genie_lngamma_mpfr (NODE_T * p)
 
 void genie_gamma_inc_real_mpfr (NODE_T * p)
 {
-  A68_REAL x, s;
-  POP_OBJECT (p, &x, A68_REAL);
-  POP_OBJECT (p, &s, A68_REAL);
+  A68G_REAL x, s;
+  POP_OBJECT (p, &x, A68G_REAL);
+  POP_OBJECT (p, &s, A68G_REAL);
   mpfr_t xx, ss;
-  mpfr_inits2 (A68_DOUBLE_MAN, ss, xx, NO_MPFR);
+  mpfr_inits2 (A68G_DOUBLE_MAN, ss, xx, NO_MPFR);
   mpfr_set_d (xx, VALUE (&x), DEFAULT);
   mpfr_set_d (ss, VALUE (&s), DEFAULT);
   mpfr_gamma_inc (ss, ss, xx, DEFAULT);
   CHECK_MPFR (p, ss);
-  PUSH_VALUE (p, mpfr_get_d (ss, DEFAULT), A68_REAL);
+  PUSH_VALUE (p, mpfr_get_d (ss, DEFAULT), A68G_REAL);
   mpfr_clears (ss, xx, NO_MPFR);
 }
 
 void genie_gamma_inc_double_mpfr (NODE_T * p)
 {
-  A68_LONG_REAL x, s;
-  POP_OBJECT (p, &x, A68_LONG_REAL);
-  POP_OBJECT (p, &s, A68_LONG_REAL);
+  A68G_LONG_REAL x, s;
+  POP_OBJECT (p, &x, A68G_LONG_REAL);
+  POP_OBJECT (p, &s, A68G_LONG_REAL);
   mpfr_t xx, ss;
-  mpfr_inits2 (A68_DOUBLE_MAN, ss, xx, NO_MPFR);
+  mpfr_inits2 (A68G_DOUBLE_MAN, ss, xx, NO_MPFR);
   mpfr_set_float128 (xx, VALUE (&x).f, DEFAULT);
   mpfr_set_float128 (ss, VALUE (&s).f, DEFAULT);
   mpfr_gamma_inc (ss, ss, xx, DEFAULT);
   CHECK_MPFR (p, ss);
-  PUSH_VALUE (p, dble (mpfr_get_float128 (ss, DEFAULT)), A68_LONG_REAL);
+  PUSH_VALUE (p, dble (mpfr_get_float128 (ss, DEFAULT)), A68G_LONG_REAL);
   mpfr_clears (ss, xx, NO_MPFR);
 }
 
@@ -380,7 +380,7 @@ void genie_gamma_inc_mpfr (NODE_T * p)
   int digits = DIGITS (MOID (p)), size = SIZE (MOID (p));
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *s = (MP_T *) STACK_OFFSET (-2 * size);
-  A68_SP -= size;
+  A68G_SP -= size;
   mpfr_t xx, ss;
   mpfr_inits2 (MPFR_MP_BITS, ss, xx, NO_MPFR);
   mp_to_mpfr (p, x, &xx, digits);
@@ -396,7 +396,7 @@ void genie_beta_mpfr (NODE_T * p)
   int digits = DIGITS (MOID (p)), size = SIZE (MOID (p));
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *s = (MP_T *) STACK_OFFSET (-2 * size);
-  A68_SP -= size;
+  A68G_SP -= size;
   mpfr_t xx, ss;
   mpfr_inits2 (MPFR_MP_BITS, ss, xx, NO_MPFR);
   mp_to_mpfr (p, x, &xx, digits);
@@ -412,7 +412,7 @@ void genie_ln_beta_mpfr (NODE_T * p)
   int digits = DIGITS (MOID (p)), size = SIZE (MOID (p));
   MP_T *b = (MP_T *) STACK_OFFSET (-size);
   MP_T *a = (MP_T *) STACK_OFFSET (-2 * size);
-  A68_SP -= size;
+  A68G_SP -= size;
   mpfr_t bb, aa, yy, zz;
   mpfr_inits2 (MPFR_MP_BITS, aa, bb, yy, zz, NO_MPFR);
   mp_to_mpfr (p, b, &bb, digits);
@@ -434,7 +434,7 @@ void genie_beta_inc_mpfr (NODE_T * p)
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
   MP_T *t = (MP_T *) STACK_OFFSET (-2 * size);
   MP_T *s = (MP_T *) STACK_OFFSET (-3 * size);
-  A68_SP -= 2 * size;
+  A68G_SP -= 2 * size;
   mpfr_t xx, ss, tt;
   mpfr_inits2 (MPFR_MP_BITS, ss, tt, xx, NO_MPFR);
   mp_to_mpfr (p, x, &xx, digits);
@@ -452,7 +452,7 @@ void zeroin_mpfr (NODE_T * _p_, mpfr_t * z, mpfr_t a, mpfr_t b, mpfr_t y, int (*
 {
 // 'zeroin'
 // MCA 2310 in 'ALGOL 60 Procedures in Numerical Algebra' by Th.J. Dekker
-  BOOL_T siga = A68_TRUE;
+  BOOL_T siga = A68G_TRUE;
   mpfr_t c, fa, fb, fc, tolb, eps, p, q, v, w;
   mpfr_inits2 (MPFR_MP_BITS, c, fa, fb, fc, tolb, eps, p, q, v, w, NO_MPFR);
   mpfr_set_ui (eps, 10, DEFAULT);
