@@ -43,7 +43,7 @@ void insert_alt_equals (NODE_T * p)
   GINFO (q) = new_genie_info ();
   *GINFO (q) = *GINFO (p);
   ATTRIBUTE (q) = ALT_EQUALS_SYMBOL;
-  NSYMBOL (q) = TEXT (add_token (&A68 (top_token), "="));
+  NSYMBOL (q) = TEXT (add_token (&A68G (top_token), "="));
   NEXT (p) = q;
   PREVIOUS (q) = p;
   if (NEXT (q) != NO_NODE) {
@@ -56,7 +56,7 @@ void insert_alt_equals (NODE_T * p)
 void detect_redefined_keyword (NODE_T * p, int construct)
 {
   if (p != NO_NODE && whether (p, KEYWORD, EQUALS_SYMBOL, STOP)) {
-    diagnostic (A68_SYNTAX_ERROR, p, ERROR_REDEFINED_KEYWORD, NSYMBOL (p), construct);
+    diagnostic (A68G_SYNTAX_ERROR, p, ERROR_REDEFINED_KEYWORD, NSYMBOL (p), construct);
   }
 }
 
@@ -82,18 +82,18 @@ int find_tag_definition (TABLE_T * table, char *name)
 {
   if (table != NO_TABLE) {
     int ret = 0;
-    BOOL_T found = A68_FALSE;
+    BOOL_T found = A68G_FALSE;
     for (TAG_T *s = INDICANTS (table); s != NO_TAG && !found; FORWARD (s)) {
       if (NSYMBOL (NODE (s)) == name) {
         ret += INDICANT;
-        found = A68_TRUE;
+        found = A68G_TRUE;
       }
     }
-    found = A68_FALSE;
+    found = A68G_FALSE;
     for (TAG_T *s = OPERATORS (table); s != NO_TAG && !found; FORWARD (s)) {
       if (NSYMBOL (NODE (s)) == name) {
         ret += OPERATOR;
-        found = A68_TRUE;
+        found = A68G_TRUE;
       }
     }
     if (ret == 0) {
@@ -114,7 +114,7 @@ void elaborate_bold_tags (NODE_T * p)
     if (IS (q, BOLD_TAG)) {
       switch (find_tag_definition (TABLE (q), NSYMBOL (q))) {
       case 0: {
-          diagnostic (A68_SYNTAX_ERROR, q, ERROR_UNDECLARED_TAG);
+          diagnostic (A68G_SYNTAX_ERROR, q, ERROR_UNDECLARED_TAG);
           break;
         }
       case INDICANT: {
@@ -155,7 +155,7 @@ void extract_indicants (NODE_T * p)
   NODE_T *q = p;
   while (q != NO_NODE) {
     if (IS (q, MODE_SYMBOL)) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       do {
         FORWARD (q);
         detect_redefined_keyword (q, MODE_DECLARATION);
@@ -163,14 +163,14 @@ void extract_indicants (NODE_T * p)
 // Store in the symbol table, but also in the moid list.
 // Position of definition (q) connects to this lexical level! 
           ASSERT (add_tag (TABLE (p), INDICANT, q, NO_MOID, STOP) != NO_TAG);
-          ASSERT (add_mode (&TOP_MOID (&A68_JOB), INDICANT, 0, q, NO_MOID, NO_PACK) != NO_MOID);
+          ASSERT (add_mode (&TOP_MOID (&A68G_JOB), INDICANT, 0, q, NO_MOID, NO_PACK) != NO_MOID);
           ATTRIBUTE (q) = DEFINING_INDICANT;
           FORWARD (q);
           ATTRIBUTE (q) = ALT_EQUALS_SYMBOL;
           q = skip_pack_declarer (NEXT (q));
           FORWARD (q);
         } else {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
         }
       } while (siga && q != NO_NODE && IS (q, COMMA_SYMBOL));
     } else {
@@ -183,10 +183,10 @@ void extract_indicants (NODE_T * p)
   errno=0;\
   (k) = atoi (NSYMBOL (q));\
   if (errno != 0) {\
-    diagnostic (A68_SYNTAX_ERROR, (q), ERROR_INVALID_PRIORITY);\
+    diagnostic (A68G_SYNTAX_ERROR, (q), ERROR_INVALID_PRIORITY);\
     (k) = MAX_PRIORITY;\
   } else if ((k) < 1 || (k) > MAX_PRIORITY) {\
-    diagnostic (A68_SYNTAX_ERROR, (q), ERROR_INVALID_PRIORITY);\
+    diagnostic (A68G_SYNTAX_ERROR, (q), ERROR_INVALID_PRIORITY);\
     (k) = MAX_PRIORITY;\
   }
 
@@ -197,14 +197,14 @@ void extract_priorities (NODE_T * p)
   NODE_T *q = p;
   while (q != NO_NODE) {
     if (IS (q, PRIO_SYMBOL)) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       do {
         FORWARD (q);
         detect_redefined_keyword (q, PRIORITY_DECLARATION);
 // An operator tag like ++ or && gives strange errors so we catch it here.
         if (whether (q, OPERATOR, OPERATOR, STOP)) {
           NODE_T *y = q;
-          diagnostic (A68_SYNTAX_ERROR, q, ERROR_INVALID_OPERATOR_TAG);
+          diagnostic (A68G_SYNTAX_ERROR, q, ERROR_INVALID_OPERATOR_TAG);
           ATTRIBUTE (q) = DEFINING_OPERATOR;
 // Remove one superfluous operator, and hope it was only one.           .
           NEXT (q) = NEXT_NEXT (q);
@@ -229,7 +229,7 @@ void extract_priorities (NODE_T * p)
           ASSERT (add_tag (TABLE (p), PRIO_SYMBOL, y, NO_MOID, k) != NO_TAG);
           FORWARD (q);
         } else if (whether (q, BOLD_TAG, IDENTIFIER, STOP)) {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
         } else if (whether (q, BOLD_TAG, EQUALS_SYMBOL, INT_DENOTATION, STOP)) {
           NODE_T *y = q;
           ATTRIBUTE (q) = DEFINING_OPERATOR;
@@ -249,9 +249,9 @@ void extract_priorities (NODE_T * p)
             char *sym = (char *) get_temp_heap_space ((size_t) (len + 1));
             a68g_bufcpy (sym, NSYMBOL (q), len + 1);
             sym[len - 1] = NULL_CHAR;
-            NSYMBOL (q) = TEXT (add_token (&A68 (top_token), sym));
+            NSYMBOL (q) = TEXT (add_token (&A68G (top_token), sym));
             if (len > 2 && NSYMBOL (q)[len - 2] == ':' && NSYMBOL (q)[len - 3] != '=') {
-              diagnostic (A68_SYNTAX_ERROR, q, ERROR_OPERATOR_INVALID_END);
+              diagnostic (A68G_SYNTAX_ERROR, q, ERROR_OPERATOR_INVALID_END);
             }
             ATTRIBUTE (q) = DEFINING_OPERATOR;
             insert_alt_equals (q);
@@ -262,10 +262,10 @@ void extract_priorities (NODE_T * p)
             ASSERT (add_tag (TABLE (p), PRIO_SYMBOL, y, NO_MOID, k) != NO_TAG);
             FORWARD (q);
           } else {
-            siga = A68_FALSE;
+            siga = A68G_FALSE;
           }
         } else {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
         }
       } while (siga && q != NO_NODE && IS (q, COMMA_SYMBOL));
     } else {
@@ -283,7 +283,7 @@ void extract_operators (NODE_T * p)
     if (!IS (q, OP_SYMBOL)) {
       FORWARD (q);
     } else {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
 // Skip operator plan.
       if (NEXT (q) != NO_NODE && IS (NEXT (q), OPEN_SYMBOL)) {
         q = skip_pack_declarer (NEXT (q));
@@ -295,7 +295,7 @@ void extract_operators (NODE_T * p)
           detect_redefined_keyword (q, OPERATOR_DECLARATION);
 // Unacceptable operator tags like ++ or && could give strange errors.
           if (whether (q, OPERATOR, OPERATOR, STOP)) {
-            diagnostic (A68_SYNTAX_ERROR, q, ERROR_INVALID_OPERATOR_TAG);
+            diagnostic (A68G_SYNTAX_ERROR, q, ERROR_INVALID_OPERATOR_TAG);
             ATTRIBUTE (q) = DEFINING_OPERATOR;
             ASSERT (add_tag (TABLE (p), OP_SYMBOL, q, NO_MOID, STOP) != NO_TAG);
             NEXT (q) = NEXT_NEXT (q);   // Remove one superfluous operator, and hope it was only one
@@ -310,7 +310,7 @@ void extract_operators (NODE_T * p)
             ATTRIBUTE (q) = ALT_EQUALS_SYMBOL;
             q = skip_unit (q);
           } else if (whether (q, BOLD_TAG, IDENTIFIER, STOP)) {
-            siga = A68_FALSE;
+            siga = A68G_FALSE;
           } else if (whether (q, BOLD_TAG, EQUALS_SYMBOL, STOP)) {
             ATTRIBUTE (q) = DEFINING_OPERATOR;
             ASSERT (add_tag (TABLE (p), OP_SYMBOL, q, NO_MOID, STOP) != NO_TAG);
@@ -324,9 +324,9 @@ void extract_operators (NODE_T * p)
               char *sym = (char *) get_temp_heap_space ((size_t) (len + 1));
               a68g_bufcpy (sym, NSYMBOL (q), len + 1);
               sym[len - 1] = NULL_CHAR;
-              NSYMBOL (q) = TEXT (add_token (&A68 (top_token), sym));
+              NSYMBOL (q) = TEXT (add_token (&A68G (top_token), sym));
               if (len > 2 && NSYMBOL (q)[len - 2] == ':' && NSYMBOL (q)[len - 3] != '=') {
-                diagnostic (A68_SYNTAX_ERROR, q, ERROR_OPERATOR_INVALID_END);
+                diagnostic (A68G_SYNTAX_ERROR, q, ERROR_OPERATOR_INVALID_END);
               }
               ATTRIBUTE (q) = DEFINING_OPERATOR;
               insert_alt_equals (q);
@@ -334,10 +334,10 @@ void extract_operators (NODE_T * p)
               FORWARD (q);
               q = skip_unit (q);
             } else {
-              siga = A68_FALSE;
+              siga = A68G_FALSE;
             }
           } else {
-            siga = A68_FALSE;
+            siga = A68G_FALSE;
           }
         } while (siga && q != NO_NODE && IS (q, COMMA_SYMBOL));
       }
@@ -368,7 +368,7 @@ void extract_identities (NODE_T * p)
   NODE_T *q = p;
   while (q != NO_NODE) {
     if (whether (q, DECLARER, IDENTIFIER, EQUALS_SYMBOL, STOP)) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       do {
         if (whether ((FORWARD (q)), IDENTIFIER, EQUALS_SYMBOL, STOP)) {
           ASSERT (add_tag (TABLE (p), IDENTIFIER, q, NO_MOID, NORMAL_IDENTIFIER) != NO_TAG);
@@ -378,13 +378,13 @@ void extract_identities (NODE_T * p)
           q = skip_unit (q);
         } else if (whether (q, IDENTIFIER, ASSIGN_SYMBOL, STOP)) {
 // Handle common error in ALGOL 68 programs.
-          diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
+          diagnostic (A68G_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
           ASSERT (add_tag (TABLE (p), IDENTIFIER, q, NO_MOID, NORMAL_IDENTIFIER) != NO_TAG);
           ATTRIBUTE (q) = DEFINING_IDENTIFIER;
           ATTRIBUTE (FORWARD (q)) = ALT_EQUALS_SYMBOL;
           q = skip_unit (q);
         } else {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
         }
       } while (siga && q != NO_NODE && IS (q, COMMA_SYMBOL));
     } else {
@@ -400,20 +400,20 @@ void extract_variables (NODE_T * p)
   NODE_T *q = p;
   while (q != NO_NODE) {
     if (whether (q, DECLARER, IDENTIFIER, STOP)) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       do {
         FORWARD (q);
         if (whether (q, IDENTIFIER, STOP)) {
           if (whether (q, IDENTIFIER, EQUALS_SYMBOL, STOP)) {
 // Handle common error in ALGOL 68 programs.
-            diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
+            diagnostic (A68G_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
             ATTRIBUTE (NEXT (q)) = ASSIGN_SYMBOL;
           }
           ASSERT (add_tag (TABLE (p), IDENTIFIER, q, NO_MOID, NORMAL_IDENTIFIER) != NO_TAG);
           ATTRIBUTE (q) = DEFINING_IDENTIFIER;
           q = skip_unit (q);
         } else {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
         }
       } while (siga && q != NO_NODE && IS (q, COMMA_SYMBOL));
     } else {
@@ -429,24 +429,24 @@ void extract_proc_identities (NODE_T * p)
   NODE_T *q = p;
   while (q != NO_NODE) {
     if (whether (q, PROC_SYMBOL, IDENTIFIER, EQUALS_SYMBOL, STOP)) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       do {
         FORWARD (q);
         if (whether (q, IDENTIFIER, EQUALS_SYMBOL, STOP)) {
           TAG_T *t = add_tag (TABLE (p), IDENTIFIER, q, NO_MOID, NORMAL_IDENTIFIER);
-          IN_PROC (t) = A68_TRUE;
+          IN_PROC (t) = A68G_TRUE;
           ATTRIBUTE (q) = DEFINING_IDENTIFIER;
           ATTRIBUTE (FORWARD (q)) = ALT_EQUALS_SYMBOL;
           q = skip_unit (q);
         } else if (whether (q, IDENTIFIER, ASSIGN_SYMBOL, STOP)) {
 // Handle common error in ALGOL 68 programs.
-          diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
+          diagnostic (A68G_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
           ASSERT (add_tag (TABLE (p), IDENTIFIER, q, NO_MOID, NORMAL_IDENTIFIER) != NO_TAG);
           ATTRIBUTE (q) = DEFINING_IDENTIFIER;
           ATTRIBUTE (FORWARD (q)) = ALT_EQUALS_SYMBOL;
           q = skip_unit (q);
         } else {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
         }
       } while (siga && q != NO_NODE && IS (q, COMMA_SYMBOL));
     } else {
@@ -462,7 +462,7 @@ void extract_proc_variables (NODE_T * p)
   NODE_T *q = p;
   while (q != NO_NODE) {
     if (whether (q, PROC_SYMBOL, IDENTIFIER, STOP)) {
-      BOOL_T siga = A68_TRUE;
+      BOOL_T siga = A68G_TRUE;
       do {
         FORWARD (q);
         if (whether (q, IDENTIFIER, ASSIGN_SYMBOL, STOP)) {
@@ -471,13 +471,13 @@ void extract_proc_variables (NODE_T * p)
           q = skip_unit (FORWARD (q));
         } else if (whether (q, IDENTIFIER, EQUALS_SYMBOL, STOP)) {
 // Handle common error in ALGOL 68 programs.
-          diagnostic (A68_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
+          diagnostic (A68G_SYNTAX_ERROR, q, ERROR_SYNTAX_MIXED_DECLARATION);
           ASSERT (add_tag (TABLE (p), IDENTIFIER, q, NO_MOID, NORMAL_IDENTIFIER) != NO_TAG);
           ATTRIBUTE (q) = DEFINING_IDENTIFIER;
           ATTRIBUTE (FORWARD (q)) = ASSIGN_SYMBOL;
           q = skip_unit (q);
         } else {
-          siga = A68_FALSE;
+          siga = A68G_FALSE;
         }
       } while (siga && q != NO_NODE && IS (q, COMMA_SYMBOL));
     } else {
@@ -535,7 +535,7 @@ void extract_declarations (NODE_T * p)
           PRIO (INFO (q)) = 0;
         }
       } else {
-        diagnostic (A68_SYNTAX_ERROR, q, ERROR_UNDECLARED_TAG);
+        diagnostic (A68G_SYNTAX_ERROR, q, ERROR_UNDECLARED_TAG);
         PRIO (INFO (q)) = 1;
       }
     }
