@@ -51,36 +51,36 @@
 
 void genie_pq_connectdb (NODE_T * p)
 {
-  A68_REF ref_string, ref_file, conninfo;
+  A68G_REF ref_string, ref_file, conninfo;
   POP_REF (p, &ref_string);
   CHECK_REF (p, ref_string, M_REF_STRING);
   POP_REF (p, &conninfo);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
   if (IS_IN_HEAP (&ref_file) && !IS_IN_HEAP (&ref_string)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_SCOPE_DYNAMIC_1, M_REF_STRING);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SCOPE_DYNAMIC_1, M_REF_STRING);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   } else if (IS_IN_FRAME (&ref_file) && IS_IN_FRAME (&ref_string)) {
     if (REF_SCOPE (&ref_string) > REF_SCOPE (&ref_file)) {
-      diagnostic (A68_RUNTIME_ERROR, p, ERROR_SCOPE_DYNAMIC_1, M_REF_STRING);
-      exit_genie (p, A68_RUNTIME_ERROR);
+      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_SCOPE_DYNAMIC_1, M_REF_STRING);
+      exit_genie (p, A68G_RUNTIME_ERROR);
     }
   }
 // Initialise the file.
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   if (OPENED (file)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_FILE_ALREADY_OPEN);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_ALREADY_OPEN);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   STATUS (file) = INIT_MASK;
-  CHANNEL (file) = A68 (associate_channel);
-  OPENED (file) = A68_TRUE;
-  OPEN_EXCLUSIVE (file) = A68_FALSE;
-  READ_MOOD (file) = A68_FALSE;
-  WRITE_MOOD (file) = A68_FALSE;
-  CHAR_MOOD (file) = A68_FALSE;
-  DRAW_MOOD (file) = A68_FALSE;
-  TMP_FILE (file) = A68_FALSE;
+  CHANNEL (file) = A68G (associate_channel);
+  OPENED (file) = A68G_TRUE;
+  OPEN_EXCLUSIVE (file) = A68G_FALSE;
+  READ_MOOD (file) = A68G_FALSE;
+  WRITE_MOOD (file) = A68G_FALSE;
+  CHAR_MOOD (file) = A68G_FALSE;
+  DRAW_MOOD (file) = A68G_FALSE;
+  TMP_FILE (file) = A68G_FALSE;
   if (INITIALISED (&(IDENTIFICATION (file))) && !IS_NIL (IDENTIFICATION (file))) {
     UNBLOCK_GC_HANDLE (&(IDENTIFICATION (file)));
   }
@@ -97,7 +97,7 @@ void genie_pq_connectdb (NODE_T * p)
   STREAM (&DEVICE (file)) = NULL;
   set_default_event_procedures (file);
 // Establish a connection.
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, conninfo));
+  A68G_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, conninfo));
   CONNECTION (file) = PQconnectdb (a_to_c_string (p, DEREF (char, &ref_z), conninfo));
   RESULT (file) = NO_PGRESULT;
   if (CONNECTION (file) == NO_PGCONN) {
@@ -115,10 +115,10 @@ void genie_pq_connectdb (NODE_T * p)
 
 void genie_pq_finish (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -137,10 +137,10 @@ void genie_pq_finish (NODE_T * p)
 
 void genie_pq_reset (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -157,11 +157,11 @@ void genie_pq_reset (NODE_T * p)
 
 void genie_pq_exec (NODE_T * p)
 {
-  A68_REF query, ref_file;
+  A68G_REF query, ref_file;
   POP_REF (p, &query);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -170,7 +170,7 @@ void genie_pq_exec (NODE_T * p)
   if (RESULT (file) != NO_PGRESULT) {
     PQclear (RESULT (file));
   }
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, query));
+  A68G_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, query));
   RESULT (file) = PQexec (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), query));
   if ((PQresultStatus (RESULT (file)) != PGRES_TUPLES_OK)
       && (PQresultStatus (RESULT (file)) != PGRES_COMMAND_OK)) {
@@ -184,19 +184,19 @@ void genie_pq_exec (NODE_T * p)
 
 void genie_pq_parameterstatus (NODE_T * p)
 {
-  A68_REF parameter, ref_file;
+  A68G_REF parameter, ref_file;
   POP_REF (p, &parameter);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, parameter));
+  A68G_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, parameter));
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, (char *) PQparameterStatus (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), parameter)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, (char *) PQparameterStatus (CONNECTION (file), a_to_c_string (p, DEREF (char, &ref_z), parameter)), DEFAULT_WIDTH);
     PUSH_PRIMAL (p, 0, INT);
   } else {
     PUSH_PRIMAL (p, -3, INT);
@@ -207,10 +207,10 @@ void genie_pq_parameterstatus (NODE_T * p)
 
 void genie_pq_cmdstatus (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -221,7 +221,7 @@ void genie_pq_cmdstatus (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQcmdStatus (RESULT (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQcmdStatus (RESULT (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -233,10 +233,10 @@ void genie_pq_cmdstatus (NODE_T * p)
 
 void genie_pq_cmdtuples (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -247,7 +247,7 @@ void genie_pq_cmdtuples (NODE_T * p)
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQcmdTuples (RESULT (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQcmdTuples (RESULT (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -259,10 +259,10 @@ void genie_pq_cmdtuples (NODE_T * p)
 
 void genie_pq_ntuples (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -279,10 +279,10 @@ void genie_pq_ntuples (NODE_T * p)
 
 void genie_pq_nfields (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -299,12 +299,12 @@ void genie_pq_nfields (NODE_T * p)
 
 void genie_pq_fname (NODE_T * p)
 {
-  A68_INT a68g_index; A68_REF ref_file;
-  POP_OBJECT (p, &a68g_index, A68_INT);
+  A68G_INT a68g_index; A68G_REF ref_file;
+  POP_OBJECT (p, &a68g_index, A68G_INT);
   CHECK_INIT (p, INITIALISED (&a68g_index), M_INT);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -316,11 +316,11 @@ void genie_pq_fname (NODE_T * p)
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
   if (VALUE (&a68g_index) < 1 || VALUE (&a68g_index) > upb) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQfname (RESULT (file), VALUE (&a68g_index) - 1), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQfname (RESULT (file), VALUE (&a68g_index) - 1), DEFAULT_WIDTH);
     STRPOS (file) = 0;
   }
   PUSH_PRIMAL (p, 0, INT);
@@ -330,11 +330,11 @@ void genie_pq_fname (NODE_T * p)
 
 void genie_pq_fnumber (NODE_T * p)
 {
-  A68_REF name, ref_file;
+  A68G_REF name, ref_file;
   POP_REF (p, &name);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -344,7 +344,7 @@ void genie_pq_fnumber (NODE_T * p)
     PUSH_PRIMAL (p, -2, INT);
     return;
   }
-  A68_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, name));
+  A68G_REF ref_z = heap_generator (p, M_C_STRING, 1 + a68g_string_size (p, name));
   int k = PQfnumber (RESULT (file), a_to_c_string (p, DEREF (char, &ref_z), name));
   if (k == -1) {
     PUSH_PRIMAL (p, -3, INT);
@@ -357,12 +357,12 @@ void genie_pq_fnumber (NODE_T * p)
 
 void genie_pq_fformat (NODE_T * p)
 {
-  A68_INT a68g_index; A68_REF ref_file;
-  POP_OBJECT (p, &a68g_index, A68_INT);
+  A68G_INT a68g_index; A68G_REF ref_file;
+  POP_OBJECT (p, &a68g_index, A68G_INT);
   CHECK_INIT (p, INITIALISED (&a68g_index), M_INT);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -374,8 +374,8 @@ void genie_pq_fformat (NODE_T * p)
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
   if (VALUE (&a68g_index) < 1 || VALUE (&a68g_index) > upb) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   PUSH_PRIMAL (p, PQfformat (RESULT (file), VALUE (&a68g_index) - 1), INT);
 }
@@ -384,14 +384,14 @@ void genie_pq_fformat (NODE_T * p)
 
 void genie_pq_getvalue (NODE_T * p)
 {
-  A68_INT row, column; A68_REF ref_file;
-  POP_OBJECT (p, &column, A68_INT);
+  A68G_INT row, column; A68G_REF ref_file;
+  POP_OBJECT (p, &column, A68G_INT);
   CHECK_INIT (p, INITIALISED (&column), M_INT);
-  POP_OBJECT (p, &row, A68_INT);
+  POP_OBJECT (p, &row, A68G_INT);
   CHECK_INIT (p, INITIALISED (&row), M_INT);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -403,21 +403,21 @@ void genie_pq_getvalue (NODE_T * p)
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
   if (VALUE (&column) < 1 || VALUE (&column) > upb) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQntuples (RESULT (file)) : 0);
   if (VALUE (&row) < 1 || VALUE (&row) > upb) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   char *str = PQgetvalue (RESULT (file), VALUE (&row) - 1, VALUE (&column) - 1);
   if (str == NULL) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_NO_QUERY_RESULT);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_NO_QUERY_RESULT);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -429,14 +429,14 @@ void genie_pq_getvalue (NODE_T * p)
 
 void genie_pq_getisnull (NODE_T * p)
 {
-  A68_INT row, column; A68_REF ref_file;
-  POP_OBJECT (p, &column, A68_INT);
+  A68G_INT row, column; A68G_REF ref_file;
+  POP_OBJECT (p, &column, A68G_INT);
   CHECK_INIT (p, INITIALISED (&column), M_INT);
-  POP_OBJECT (p, &row, A68_INT);
+  POP_OBJECT (p, &row, A68G_INT);
   CHECK_INIT (p, INITIALISED (&row), M_INT);
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -448,13 +448,13 @@ void genie_pq_getisnull (NODE_T * p)
   }
   int upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQnfields (RESULT (file)) : 0);
   if (VALUE (&column) < 1 || VALUE (&column) > upb) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   upb = (PQresultStatus (RESULT (file)) == PGRES_TUPLES_OK ? PQntuples (RESULT (file)) : 0);
   if (VALUE (&row) < 1 || VALUE (&row) > upb) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INDEX_OUT_OF_BOUNDS);
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
   PUSH_PRIMAL (p, PQgetisnull (RESULT (file), VALUE (&row) - 1, VALUE (&column) - 1), INT);
 }
@@ -469,7 +469,7 @@ char *pq_edit (char *str)
     static BUFFER edt;
     char *q = edt;
     int newlines = 0, len = (int) strlen (str);
-    BOOL_T suppress_blank = A68_FALSE;
+    BOOL_T suppress_blank = A68G_FALSE;
     while (len > 0 && str[len - 1] == NEWLINE_CHAR) {
       str[len - 1] = NULL_CHAR;
       len = (int) strlen (str);
@@ -485,7 +485,7 @@ char *pq_edit (char *str)
         } else {
           *(q++) = BLANK_CHAR;
         }
-        suppress_blank = A68_TRUE;
+        suppress_blank = A68G_TRUE;
         str++;
       } else if (IS_SPACE (str[0])) {
         if (suppress_blank) {
@@ -495,11 +495,11 @@ char *pq_edit (char *str)
             *(q++) = BLANK_CHAR;
           }
           str++;
-          suppress_blank = A68_TRUE;
+          suppress_blank = A68G_TRUE;
         }
       } else {
         *(q++) = *(str++);
-        suppress_blank = A68_FALSE;
+        suppress_blank = A68G_FALSE;
       }
     }
     if (newlines > 0) {
@@ -514,10 +514,10 @@ char *pq_edit (char *str)
 
 void genie_pq_errormessage (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -534,7 +534,7 @@ void genie_pq_errormessage (NODE_T * p)
     } else {
       a68g_bufcpy (str, "no error message available", BUFFER_SIZE);
     }
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -546,10 +546,10 @@ void genie_pq_errormessage (NODE_T * p)
 
 void genie_pq_resulterrormessage (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -570,7 +570,7 @@ void genie_pq_resulterrormessage (NODE_T * p)
     } else {
       a68g_bufcpy (str, "no error message available", BUFFER_SIZE);
     }
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, str, DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -582,17 +582,17 @@ void genie_pq_resulterrormessage (NODE_T * p)
 
 void genie_pq_db (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQdb (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQdb (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -604,17 +604,17 @@ void genie_pq_db (NODE_T * p)
 
 void genie_pq_user (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQuser (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQuser (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -626,17 +626,17 @@ void genie_pq_user (NODE_T * p)
 
 void genie_pq_pass (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQpass (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQpass (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -648,17 +648,17 @@ void genie_pq_pass (NODE_T * p)
 
 void genie_pq_host (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQhost (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQhost (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -670,17 +670,17 @@ void genie_pq_host (NODE_T * p)
 
 void genie_pq_port (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQport (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQport (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -692,17 +692,17 @@ void genie_pq_port (NODE_T * p)
 
 void genie_pq_tty (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQtty (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQtty (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -714,17 +714,17 @@ void genie_pq_tty (NODE_T * p)
 
 void genie_pq_options (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
     return;
   }
   if (!IS_NIL (STRING (file))) {
-    *DEREF (A68_REF, &STRING (file)) = c_to_a_string (p, PQoptions (CONNECTION (file)), DEFAULT_WIDTH);
+    *DEREF (A68G_REF, &STRING (file)) = c_to_a_string (p, PQoptions (CONNECTION (file)), DEFAULT_WIDTH);
     STRPOS (file) = 0;
     PUSH_PRIMAL (p, 0, INT);
   } else {
@@ -736,10 +736,10 @@ void genie_pq_options (NODE_T * p)
 
 void genie_pq_protocolversion (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -756,10 +756,10 @@ void genie_pq_protocolversion (NODE_T * p)
 
 void genie_pq_serverversion (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -776,10 +776,10 @@ void genie_pq_serverversion (NODE_T * p)
 
 void genie_pq_socket (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
@@ -796,10 +796,10 @@ void genie_pq_socket (NODE_T * p)
 
 void genie_pq_backendpid (NODE_T * p)
 {
-  A68_REF ref_file;
+  A68G_REF ref_file;
   POP_REF (p, &ref_file);
   CHECK_REF (p, ref_file, M_REF_FILE);
-  A68_FILE *file = FILE_DEREF (&ref_file);
+  A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
   if (CONNECTION (file) == NO_PGCONN) {
     PUSH_PRIMAL (p, -1, INT);
